@@ -57,7 +57,7 @@ class NatGeoProvider : public PotdProvider
          * Note: This method returns only a valid image after the
          *       finished() signal has been emitted.
          */
-        virtual QImage image() const;
+        QImage image() const Q_DECL_OVERRIDE;
 
     private:
       class Private;
